@@ -38,7 +38,7 @@ class BackendClient:
         self.client = MatrixClient(url, self._message, self._membership_event)
 
         # construct matrix user name with user and domain name
-        self.user = "@{}:{}".format(user, domain)
+        self.user = f"@{user}:{domain}"
 
         # sync token and connection config
         self.settings = SimpleNamespace(
@@ -104,18 +104,18 @@ class BackendClient:
         if event_type == "invite":
             user_msg = Message.chat_user(self.account, room_id, invited_user,
                                          invited_user, event_type)
-            msg = "*** {} invited {} to {}. ***".format(sender_name,
-                                                        invited_user,
-                                                        room_name)
+            msg = (f"*** {sender_name} invited {invited_user} "
+                   f"to {room_name}. ***")
+
         if event_type == "join":
             user_msg = Message.chat_user(self.account, room_id, sender_id,
                                          invited_user, event_type)
-            msg = "*** {} joined {}. ***".format(invited_user, room_name)
+            msg = f"*** {invited_user} joined {room_name}. ***"
 
         if event_type == "leave":
             user_msg = Message.chat_user(self.account, room_id, sender_id,
                                          sender_name, event_type)
-            msg = "*** {} left {}. ***".format(sender_name, room_name)
+            msg = f"*** {sender_name} left {room_name}. ***"
 
         # generic event, return as message
         # TODO: change parsing in nuqql and use char + / + sender here?
@@ -335,13 +335,14 @@ class BackendClient:
         os.chmod(self.account.config.get_dir(), stat.S_IRWXU)
         sync_token_file = self.account.config.get_dir() / f"sync_token{acc_id}"
         if not sync_token_file.exists():
-            open(sync_token_file, "a").close()
+            with open(sync_token_file, "a", encoding='UTF-8'):
+                pass
 
         # make sure only user can read/write file before using it
         os.chmod(sync_token_file, stat.S_IRUSR | stat.S_IWUSR)
 
         try:
-            with open(sync_token_file, "r") as token_file:
+            with open(sync_token_file, "r", encoding='UTF-8') as token_file:
                 token = token_file.readline()
         except OSError:
             token = ""
@@ -362,7 +363,7 @@ class BackendClient:
         sync_token_file = self.account.config.get_dir() / f"sync_token{acc_id}"
 
         try:
-            with open(sync_token_file, "w") as token_file:
+            with open(sync_token_file, "w", encoding='UTF-8') as token_file:
                 token_file.write(new)
         except OSError:
             return old
