@@ -23,7 +23,7 @@ if TYPE_CHECKING:   # imports for typing
 
 
 # matrixd version
-VERSION = "0.5.0"
+VERSION = "0.6.0"
 
 
 class BackendServer:
@@ -97,8 +97,7 @@ class BackendServer:
         # nuqql sends a html-escaped message; construct "plain-text" version
         # and xhtml version using nuqql's message and use them as message body
         # later
-        html_msg = \
-            '<body xmlns="http://www.w3.org/1999/xhtml">{}</body>'.format(msg)
+        html_msg = f'<body xmlns="http://www.w3.org/1999/xhtml">{msg}</body>'
         msg = html.unescape(msg)
         msg = "\n".join(re.split("<br/>", msg, flags=re.IGNORECASE))
 
@@ -167,7 +166,8 @@ class BackendServer:
 
         return ""
 
-    async def _help_account_add(self, _account: Optional["Account"],
+    @staticmethod
+    async def _help_account_add(_account: Optional["Account"],
                                 _cmd: Callback, _params: Tuple) -> str:
         """
         Handle account add help event
